@@ -42,6 +42,8 @@
 ( cd opt/kde/share/doc/HTML/fr/korn ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kppp ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kppp ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/krdc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/krdc ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/krec ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/krec ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/krfb ; rm -rf common )
@@ -88,6 +90,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kandy ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kcalc ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kdcop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kdcop ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kdesu ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kcron ; rm -rf common )
@@ -112,6 +116,8 @@
 ( cd opt/kde/share/doc/HTML/fr/ksame ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/ksirc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/ksirc ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/ktnef ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/ktnef ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/ksysv ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/ksysv ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/ktron ; rm -rf common )
@@ -192,6 +198,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kioslave ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/knetattach ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/knetattach ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kxconfig ; rm -rf common )
@@ -218,6 +226,8 @@
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/6.png 6.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 7.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/7.png 7.png )
+( cd opt/kde/share/doc/HTML/fr/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 8.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 9.png )
@@ -248,6 +258,8 @@
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/fr/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf doctop1.png )
@@ -260,8 +272,12 @@
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/fr/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/fr/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf doctop1a.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf 10.png )
@@ -278,6 +294,10 @@
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf header.html )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/fr/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/fr/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/top-left.png top-left.png )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/fr/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/fr/common ; rm -rf kde-localised.css.template )
@@ -450,8 +470,6 @@
 ( cd opt/kde/share/doc/HTML/fr/kmines ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kmouth ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kmouth ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
-( cd opt/kde/share/doc/HTML/fr/kmplot ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fr/kmplot ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/knotes ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/knotes ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kpager ; rm -rf common )
@@ -494,6 +512,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kuickshow ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kiconedit ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kmahjongg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kmahjongg ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/klettres ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kfouleggs ; rm -rf common )
@@ -550,6 +570,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/kinfocenter/ioports ; rm -rf common )
@@ -560,6 +582,8 @@
 ( cd opt/kde/share/doc/HTML/fr/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/konqueror ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
+( cd opt/kde/share/doc/HTML/fr/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fr/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/fr/korganizer ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
 ( cd opt/kde/share/doc/HTML/fr/atlantik ; rm -rf common )
